Stan Math Library: stan/math/prim/mat/meta/scalar_type.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

scalar_type.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_META_SCALAR_TYPE_HPP
2 #define STAN_MATH_PRIM_MAT_META_SCALAR_TYPE_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5 #include <stan/math/prim/mat/meta/is_vector.hpp>
6 #include <stan/math/prim/mat/meta/value_type.hpp>
7 #include <stan/math/prim/scal/meta/scalar_type.hpp>
8
9 namespace stan {
10
11 template <typename T>
12 struct scalar_type<Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic> > {
13 typedef typename scalar_type<T>::type type;
14 };
15
16 }
17 #endif
stan::scalar_type
Metaprogram structure to determine the base scalar type of a template argument.
Definition: scalar_type.hpp:34
stan
Definition: log_sum_exp.hpp:8
is_vector.hpp
stan::scalar_type::type
scalar_type_helper< is_vector< T >::value, T >::type type
Definition: scalar_type.hpp:35
Eigen
(Expert) Numerical traits for algorithmic differentiation variables.
Definition: Eigen_NumTraits.hpp:8
value_type.hpp
stan::scalar_type< Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > >::type
scalar_type< T >::type type
Definition: scalar_type.hpp:13
Eigen.hpp
scalar_type.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.